---
title: 글로벌_해외결제 대행사별 위험업종 유형
category: 결제서비스 (채널설정 및 이용안내) > 결제유형 > 해외결제
tags:
  - 해외결제
  - 크로스보더
pgCompanies:
  - KG이니시스
searchTags:
  - 페이레터
  - 심사불가
  - 판매불가
  - 일본
  - 심사기준
  - 이니시스 심사기준
  - Rm기준
  - 위험업종
  - 일본결제
  - kg이니시스
datetime: 2025-03-12T05:48:45.678Z
---

<Callout content="✔ PG 계약을 위해서는  온라인 결제시 판매하는 서비스(상품) 유형을 
1차적으로 심사를 하고 입점 가능여부가 결정됩니다.

✔ PG사별 입점 심사 기준(RM)정책은 카드사 등록불가 업종 기준을 바탕으로 적용됩니다. 
" title="" />

## 📌결제대행사 입점이 어려운 업종 유형

아래와 같은 등록 불가 업종이 아니더라도 PG사(결제대행사)에서 운영 시 경험적으로 결제 사고가 빈번했던 서비스 형태나 판매 방식을 기준으로 입점(가입)을 거절할 수도 있습니다.\
\
또한 카드사 및 PG사(결제대행사) 등록 불가 기준은 사회적 이슈 등에 따라 리스크가 반영되어 수시로 변경될 수 있습니다.

## KG이니시스\_일본결제 심사조건

- 일본 특정상거래법에 의거한 표시사항 및 일본
  개인정보보호 방침 기재 필수\
  Sample 참고 : <https://www.tixply.io/>
- 페이지 내 컨텐츠 일본어 , 통화는 엔화 기준 표기
- 홈페이지 URL의 경우 http\://URL 형태로 신청

### 조건부 판매 가능 상품 안내

아래 상품은 조건이 충족될 경우에만 심사 가능하며, \
조건이 충족된 경우라 하더라도 일본결제 원천사 측에서 심사 승인이 거절될 가능성이 있습니다.

- 상품 : 콘택트 렌즈, 컬러 렌즈 및 의료기기(도수여부,일회용 여부 관계없이 동일)

<Indent level="1">

- 심사 가능 조건 \
  해외에서 일본 국내 사용자에게 발송할 경우
  \[고도관리의료기기]의 판매업 허가를 취득하고 있는경우
  웹사이트에\[허가번호],\[관리자]가 명시된 경우\\

  일본으로 선수입 후 국내 사용자에게 발송할 경우
  \[고도관리의료기기]판매업허가+제1종 의료기기 제조판매업 허가를 취득하고 있는 경우

</Indent>

- 상품 : 가정용 전기 마사지 제품 혹은 관리 의료기기

<Indent level="1">

- 심사 가능 조건 \
  \[관리 의료기기]의 판매업 허가를 취득하고 있는 경우
  웹사이트에 \[허가번호]가 기재된 경우

</Indent>

- **상품 :  여행업**

<Indent level="1">

- 심사 가능 조건 \
  웹사이트에 \[여행업등록증],\[여행약관,조건서]가 기재된 경우

</Indent>

- 상**품 :  주류업**

<Indent level="1">

- 심사 가능 조건 \
  웹사이트에\[주류판매허가번호]가 기재된 경우

</Indent>

- **상품 :  화장품류, 건강식품**

<Indent level="1">

- 심사 가능 조건 \
  웹사이트에 성분, 제조원, 효과 및 효능의 개인차가 있음을 안내하는 문구, 성분이 몸에 맞지 않을 경우 \
  이용을 중지하고 의사에게 상담하라는 내용 등의 안내가 있을 경우

</Indent>

- **상품 :  맞춤 및 예약상품**

<Indent level="1">

- 심사 가능 조건 \
  공매가 아니거나, 결함이 없는 경우
  해당 상품의 배송일이 명시되어 있는 경우

</Indent>

- **상품 :  맞선파티 관련**

<Indent level="1">

- 심사 가능 조건 \
  이용자(참가자)에 대해 엄격한 심사 기준을 가지고 운영할 것

</Indent>

- **상품 :  생선**

<Indent level="1">

- 심사 가능 조건 \
  \[어패류 판매업]의 허가를 취득하고 있는 경우

</Indent>

- \*\*상품 : \*\*육류

<Indent level="1">

- 심사 가능 조건 \
  \[육류 판매업]의 허가를 취득하고 있는 경우

</Indent>

- **상품 :  중고품**

<Indent level="1">

- 심사 가능 조건 \
  웹사이트에\[고물상 허가 신청 번호]가 명시되어 있는 경우

</Indent>

### 심사 불가 상품 안내

- 상품

<Indent level="1">

- 금권류 \
  \- 수표, 고액, 상품권, 프리페이드카드, 회수권, 인지, 디스카운트항공권,  주식,유가증권

- 외화 환전

- 범죄에 사용될 우려가 있는 상품, 위법 상품\
  \- 워싱턴 조약 지정품(상아, 비단뱀, 타조, 악어등)\
  \- 범죄를 유발 하는 물품(최루 스프레이,모델건, 스턴건, 총, 도검류, 수갑, 도청 및 도촬 용품등)\
  \- 판매법 위반 및 무면허 판매에 해당하는 상품 및 서비스

- 도검\
  \- 칼, 검, 모조칼

- 성인용품\
  \- 포르노, 어덜트 콘텐츠, 브루셀러숍

- RMT (RealMoneyTrade)\
  \- 게임 머니

- 도박\
  \- 카지노, 해외 복권, 페니 옥션

- 개인정보

- 생물

- 모금/헌금/기부금

- 정보\
  \- 고액의 현금을 얻는 정보/방법\
  \- 구체적인 설명이 없는 “돈을 쉽게 버는 방법”등의 정보\
  \- Day Trade나 FX같은 투자관련 정보\
  \- SEO 대책이나 접속 수 UP등의 WEB제작 관련 정보\
  \- 경마/파칭코 관련 정보

- 멀티 마케팅(다단계)\
  \- 네트워크 비즈니스, 멀티 상법에 의한 판매 촉진을 행하는 사이트

- 잔인/잔혹한 표현의 사이트 \
  \- 법령을 위반하지 않더라도 표현이 과격한 경우 해당됨

- 비과학적, 미신 종류\
  \- 파워스톤, 부적, 효과를 강조하는 도장, 점술 등

- 판매 금지된 의약품 \
  \- 처방전을 필요로 하는 약품 및 마약류

- 미풍양속을 위반하는 상품\
  \- 모조품등

- 견적품\
  \- 주문 접수 후 견적이 필요한 상품

- 진단 키트\
  \- 암이나 성병 등의 질병 진단 키트

- 개인 대행/구매 배송\
  \- 판매자가 책임지기 어려운 것

- 만남 주선/알선 \
  \- 승인허가 번호가 있는 경우에도 불가함

- 해외송금

- 소비자 금융 \
  \- 수납 대금을 신용카드로 지불 가능한 편의점이 있기때문에 불가

- 수험료/수강료\
  \- 편의점 단말에 전용 메뉴가 있는 편의점이 있기 때문에 불가

- 고가의 상품\
  \- 평균 단가 JPY 100,000 이상의 상품만 취급하는 사이트 승인불가(기모노, 종교용품, 고가의 브랜드등)

- 담배,전자담배

- 스팸 관련\
  \- 스팸, 피싱 사이트

</Indent>

<Callout title="KG이니시스 일본결제 서비스 이용안내 보러가기 ↗" />

## 페이레터\_해외결제 제한 업종

KOR\_제한 업종 ( ENG )

- 유사 투자자문업,투자  관련 강의 (a lecture on investment)
- 성인용품(콘돔, 젤, 페로몬향수  제외)\
  ( Adult products (excluding condoms, gels, and pheromone perfumes))
- NFT 관련 물품 및 정보 ( NFT related items and information)
- 재판매 (Reselling)
- 가상화폐 관련 물품, 정보 (Items related to virtual currency, information)
- 주류(전통주 제외) (Liquor (excluding traditional liquor))
- 순금(전용가맹점번호시 가능) (Pure gold (available with exclusive franchise number))
- 경마,경륜 (a horse race)
- 담배 (전자담배도 불가) (Tobacco (not even electronic cigarettes))
- 복권 (Lottery)
- 선불카드 (prepaid card)
- 중고차 (a used car)
- 명품 레플리카 (a luxury replica)
- 전자여권수속 (Electronic passport procedure)
- 총포,도검,무기 (guns, swords, weapons)
- 애완동물 분양 (the sale of pets)
- 보험정기결제 (regular insurance settlement)
- 성인사이트/컨텐츠 (Adult Site/Content)
- 부적 (amulet)
- 경매 (Auction)
- 사행성게임 (Gambling)
- 유흥 구인/구직 (a job search for an entertainment district)
- 대출 (Loans)
- 종교 후원금 (a religious contribution)
- 전화카드 (a telephone card)
- 도수있는 안경/선글라스/렌즈 (prescient glasses/ sunglasses/lenses)
- 다단계 (multi-level)

<Callout title="글로벌_페이레터 해외결제 서비스 안내 보러가기 ↗" />
